@@ -1,6 +1,6 @@
 /*
  *  Phusion Passenger - https://www.phusionpassenger.com/
- *  Copyright (c) 2013-2017 Phusion Holding B.V.
+ *  Copyright (c) 2013-2018 Phusion Holding B.V.
  *
  *  "Passenger", "Phusion Passenger" and "Union Station" are registered
  *  trademarks of Phusion Holding B.V.
@@ -47,13 +47,21 @@
  * don't do anything.
  */
 
+// for std::swap()
+#if __cplusplus >= 201103L
+	#include <utility>
+#else
+	#include <algorithm>
+#endif
 #include <string>
 #include <cstring>
 #include <curl/curl.h>
+#include <boost/config.hpp>
 #include <boost/foreach.hpp>
 #include <Exceptions.h>
+#include <FileTools/FileManip.h>
 #include <Utils.h>
-#include <Utils/StrIntUtils.h>
+#include <StrIntTools/StrIntUtils.h>
 
 namespace Passenger {
 
@@ -78,6 +86,15 @@ struct CurlProxyInfo {
 		  httpTunnel(false),
 		  valid(valid)
 		{ }
+
+	void swap(CurlProxyInfo &other) BOOST_NOEXCEPT_OR_NOTHROW {
+		hostAndPort.swap(other.hostAndPort);
+		credentials.swap(other.credentials);
+		std::swap(type, other.type);
+		std::swap(none, other.none);
+		std::swap(httpTunnel, other.httpTunnel);
+		std::swap(valid, other.valid);
+	}
 };
 
 inline const CurlProxyInfo
